Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(60)

Unified Diff: ios/chrome/browser/payments/shipping_address_selection_view_controller.h

Issue 2710683012: [Payment Request] Payment request summary view pending state (Closed)
Patch Set: rebase Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/chrome/browser/payments/shipping_address_selection_view_controller.h
diff --git a/ios/chrome/browser/payments/shipping_address_selection_view_controller.h b/ios/chrome/browser/payments/shipping_address_selection_view_controller.h
index 113bb73426623352c53c1b1061d8b070eb1c7a2f..024aea9849bd1ce069f57e3bec42c634218a03af 100644
--- a/ios/chrome/browser/payments/shipping_address_selection_view_controller.h
+++ b/ios/chrome/browser/payments/shipping_address_selection_view_controller.h
@@ -38,8 +38,8 @@ class AutofillProfile;
// delegate. Also offers a button to add a shipping address.
@interface ShippingAddressSelectionViewController : CollectionViewController
-// Whether or not the view is in a loading state.
-@property(nonatomic, assign) BOOL isLoading;
+// Whether or not the view is in a pending state.
+@property(nonatomic, assign, getter=isPending) BOOL pending;
// The error message to display, if any.
@property(nonatomic, copy) NSString* errorMessage;

Powered by Google App Engine
This is Rietveld 408576698